@@ -173,9 +173,9 @@ def new(ctx, app_path, **options):
     }
 
     if options["no_interaction"]:
-        ctx.command.run_auto(dst_path=app_abspath, data=data)
+        ctx.command.run_copy(dst_path=app_abspath, data=data, overwrite=True)
     else:
-        ctx.command.run_auto(dst_path=app_abspath, user_defaults=data)
+        ctx.command.run_copy(dst_path=app_abspath, user_defaults=data)
 
     ctx.command.copier_printf(action="run", msg="git init", style="OK")
     run_shell(cmd=["git", "init"], cwd=app_abspath)
